@@ -1,8 +1,17 @@
 s1 = Sys.time()
 library(MRG)
+library(tidyr)
+library(dplyr)
 # Neccessary to silence sf startup messages
 suppressMessages(library(sf))
-library(giscoR)
+if (require(giscoR, quietly = TRUE)) {
+# Read nuts borders, used for extracting smaller data set 
+  borders = gisco_get_nuts(nuts_level = 2)
+  dkb = borders[borders$CNTR_CODE == "DK",] %>% st_transform(crs = 3035)
+} else {
+  mrgpath = find.package("MRG")
+  load(file.path(mrgpath, "ex/dkb.rda"))
+}
 #'
 # These are SYNTHETIC agricultural FSS data 
 data(ifs_dk) # Census data
@@ -11,10 +20,7 @@ ifs_weight = ifs_dk %>% dplyr::filter(Sample == 1) # Extract weighted subsample
 # Create spatial data
 ifg = fssgeo(ifs_dk, locAdj = "LL")
 fsg = fssgeo(ifs_weight, locAdj = "LL")
-# Read nuts borders, used for extracting smaller data set 
-borders = gisco_get_nuts(nuts_level = 2)
 
-dkb = borders[borders$CNTR_CODE == "DK",] %>% st_transform(crs = 3035)
 ifg$dkb = st_join(ifg, dkb)$NUTS_ID
 ifg = ifg[!is.na(ifg$dkb) & ifg$dkb == "DK01",]
 fsg$dkb = st_join(fsg, dkb)$NUTS_ID
